<center>
<h1>karafuru</h1>
</center>

<div align="center">

![build](https://github.com/ChenghaoMou/karafuru/workflows/build/badge.svg) [![Python Version](https://img.shields.io/pypi/pyversions/karafuru.svg)](https://pypi.org/project/karafuru/) [![Dependencies Status](https://img.shields.io/badge/dependencies-up%20to%20date-brightgreen.svg)](https://github.com/ChenghaoMou/karafuru/pulls?utf8=%E2%9C%93&q=is%3Apr%20author%3Aapp%2Fdependabot) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) [![Security: bandit](https://img.shields.io/badge/security-bandit-green.svg)](https://github.com/PyCQA/bandit)
[![Pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/ChenghaoMou/karafuru/blob/master/.pre-commit-config.yaml) [![Semantic Versions](https://img.shields.io/badge/%F0%9F%9A%80-semantic%20versions-informational.svg)](https://github.com/ChenghaoMou/karafuru/releases) [![License](https://img.shields.io/github/license/ChenghaoMou/karafuru)](https://github.com/ChenghaoMou/karafuru/blob/master/LICENSE)

Traditional Chinese colors in your terminal
</div>

## 🚀 Features

<center>
<img src="https://raw.githubusercontent.com/ChenghaoMou/karafuru/master/colors1.png?token=AHUICOOUND5BUYWKXA3RQGS7P2LG2">
<img src="https://raw.githubusercontent.com/ChenghaoMou/karafuru/master/colors2.png?token=AHUICOJGAJTXPA6PNEMIFCC7P2LH6">
<img src="https://raw.githubusercontent.com/ChenghaoMou/karafuru/master/colors3.png?token=AHUICON627KEZ6LKE3T7WXS7P2LI6">
</center>

## Installation

```bash
pip install karafuru
```

## Usage

```bash
python -m karafuru --base [red|blue|green|yellow|black|white|dark|light|metal|all]
```

## License

[![License](https://img.shields.io/github/license/ChenghaoMou/karafuru)](https://github.com/ChenghaoMou/karafuru/blob/master/LICENSE)

This project is licensed under the terms of the `MIT` license. See [LICENSE](https://github.com/ChenghaoMou/karafuru/blob/master/LICENSE) for more details.


## Credits

- Inspired by [iroiro](https://github.com/antfu/iroiro)
- Reference:
  - [zhongguose](http://zhongguose.com/)
  - [chinese-colors](https://github.com/zerosoul/chinese-colors)
  - 色谱 中科院科技情报编委会名词室科学出版社 1957


This project was generated with [`python-package-template`](https://github.com/TezRomacH/python-package-template).
